// pages/mine/mineAccount/mineOrder/mineOrder.js
import UserApi from '../../../../net/api/userApi'
import ProApi from '../../../../net/api/projectApi'
Page({

    /**
     * 页面的初始数据
     */
    data: {
        packageList: [], //联系人列表
        pageData: {
            page: 1,
            rows: 10,
        }, //检索参数
        loadingState: 'loading', //加载状态
        listRefreshTrig: false, //list刷新状态
        isLoadMore: false, //加载更多的状态
        hasMore: true, //是否有更多数据
        showError: false,
        errorHint: '',
        allPrice: 0,
        materialPrice: 0
    },

    /**
     * 生命周期函数--监听页面加载
     */
    onLoad(options) {
        wx.setNavigationBarTitle({
            title: '套餐包',
        })
        wx.setNavigationBarColor({
            frontColor: '#000000', // 必写项，字体颜色仅支持#ffffff和#000000
            backgroundColor: '#F0F0F0', // 传递的颜色值，仅支持十六进制颜色
            animation: { // 可选项
                duration: 500,
                timingFunc: 'easeIn'
            }
        })
        this.doGetPrice()
        this.doRefreshList()
    },
    //创建
    goCreate(e) {
        const _self = this
        const item = e.currentTarget.dataset.item
        if (item.packageTotalSurplusCount > 0) {
            const price = item.packageInfoAppDTO.packageType == "MATERIAL" ? _self.data.materialPrice : _self.data.allPrice
            wx.redirectTo({
                url: '/pages/copyright/createProjectInfo/createProjectInfo?type=' + item.packageInfoAppDTO.packageType + '&price=' + price + '&isUrgent=false&pId=' + item.packageInfoId,
            })
        } else {
            this.setData({
                errorHint: '该套餐包已无剩余次数',
                showError: true
            })
        }
    },
    //详情
    goDetail(e) {
        const item = e.currentTarget.dataset.item
        wx.navigateTo({
            url: '/pages/mine/mineAccount/minePackageRecordDetail/minePackageRecordDetail?id=' + item.modifier + '&oId=' + item.packageOrderId
        })
    },
    doGetPrice() {
        wx.showLoading({
            title: '加载中...',
        })
        const _self = this
        ProApi.doGetPrice()
            .then(res => {
                wx.hideLoading()
                console.log(res)
                res.projTypes.forEach(el => {
                    if (el.type == 'ALL') {
                        _self.setData({
                            allPrice: el.price
                        })
                    } else if (el.type == 'MATERIAL') {
                        _self.setData({
                            materialPrice: el.price
                        })
                    }
                });
                _self.setData({
                    urgent: res.additional.urgent, //加急办理
                })
            }, err => {
                wx.hideLoading()
                wx.showToast({
                    title: '数据有误,请刷新页面',
                    icon: 'error'
                })
            })
    },
    //刷新列表
    doRefreshList() {
        console.log('正在刷新...')
        const _self = this
        _self.setData({
            listRefreshTrig: true,
            loadingState: 'loading',
            hasMore: true,
            'pageData.page': 1,
            isLoadMore: false
        })
        _self.doGetMinePackageList(true)
    },
    //加载更多
    doLoadMore() {
        //判断是否正在加载中 与是否存在更多数据
        const _self = this
        if (_self.data.isLoadMore || !_self.data.hasMore) {
            return
        }
        _self.setData({
            isLoadMore: true,
            'pageData.page': ++_self.data.pageData.page,
            'pageData.keywords': _self.data.keywords
        })
        _self.doGetMinePackageList(false)
    },
    //获取我的联系人列表 isRefresh false 加载更多  true 刷新
    doGetMinePackageList(isRefresh) {
        const _self = this
        _self.setData({
            packageList: isRefresh ? [] : _self.data.packageList,
            loadingState: isRefresh ? 'loading' : ''
        })
        UserApi.doGetMinePackageRecord(_self.data.pageData)
            .then(res => {
                console.log(res)
                var status = 'success'
                status = res.rows && res.rows.length > 0 ? 'success' : 'empty'
                _self.setData({
                    loadingState: isRefresh ? status : '',
                    packageList: _self.data.packageList.concat(res.rows),
                    listRefreshTrig: false,
                    isLoadMore: false
                })
                _self.setData({
                    hasMore: _self.data.packageList.length < res.total
                })
            })
            .catch(err => {
                _self.setData({
                    loadingState: 'error',
                    listRefreshTrig: false,
                    isLoadMore: false,
                    hasMore: true
                })
            })
    },

})